audiofile
=========

.. automodule:: audiofile

.. autosummary::

    read
    write
    bit_depth
    channels
    duration
    samples
    sampling_rate
    convert_to_wav

read
----

.. autofunction:: read

write
-----

.. autofunction:: write

bit_depth
---------

.. autofunction:: bit_depth

channels
--------

.. autofunction:: channels

duration
--------

.. autofunction:: duration

samples
-------

.. autofunction:: samples

sampling_rate
-------------

.. autofunction:: sampling_rate

convert_to_wav
--------------

.. autofunction:: convert_to_wav
